==> material__list-1.0.1.jar: META-INF/resources/webjars/material__list/1.0.1/constants.d.ts <==
/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
declare const cssClasses: {
    LIST_ITEM_ACTIVATED_CLASS: string;
    LIST_ITEM_CLASS: string;
    LIST_ITEM_SELECTED_CLASS: string;
    ROOT: string;
};
declare const strings: {
    ACTION_EVENT: string;
    ARIA_CHECKED: string;
    ARIA_CHECKED_CHECKBOX_SELECTOR: string;
    ARIA_CHECKED_RADIO_SELECTOR: string;
    ARIA_ORIENTATION: string;
    ARIA_ORIENTATION_HORIZONTAL: string;
    ARIA_ROLE_CHECKBOX_SELECTOR: string;
    ARIA_SELECTED: string;
    CHECKBOX_RADIO_SELECTOR: string;
    CHECKBOX_SELECTOR: string;
    CHILD_ELEMENTS_TO_TOGGLE_TABINDEX: string;
    ENABLED_ITEMS_SELECTOR: string;
    FOCUSABLE_CHILD_ELEMENTS: string;
    RADIO_SELECTOR: string;
};
export { strings, cssClasses };

==> material__list-1.1.0.jar: META-INF/resources/webjars/material__list/1.1.0/constants.d.ts <==
/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
declare const cssClasses: {
    LIST_ITEM_ACTIVATED_CLASS: string;
    LIST_ITEM_CLASS: string;
    LIST_ITEM_SELECTED_CLASS: string;
    ROOT: string;
};
declare const strings: {
    ACTION_EVENT: string;
    ARIA_CHECKED: string;
    ARIA_CHECKED_CHECKBOX_SELECTOR: string;
    ARIA_CHECKED_RADIO_SELECTOR: string;
    ARIA_CURRENT: string;
    ARIA_ORIENTATION: string;
    ARIA_ORIENTATION_HORIZONTAL: string;
    ARIA_ROLE_CHECKBOX_SELECTOR: string;
    ARIA_SELECTED: string;
    CHECKBOX_RADIO_SELECTOR: string;
    CHECKBOX_SELECTOR: string;
    CHILD_ELEMENTS_TO_TOGGLE_TABINDEX: string;
    ENABLED_ITEMS_SELECTOR: string;
    FOCUSABLE_CHILD_ELEMENTS: string;
    RADIO_SELECTOR: string;
};
declare const numbers: {
    UNSET_INDEX: number;
};
export { strings, cssClasses, numbers };
